<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:strip-space elements="*"/>
  <xsl:output indent="yes"/>

  <xsl:template match="/">
    <!-- for some reason, the oracle XSL processor is leaving out the final '?'
    that ends a processing instruction tag, so we have to put one in ourselves
    -->
    <xsl:processing-instruction name="providerDefinition">version="2.0"?</xsl:processing-instruction>
    <xsl:comment>
**** Note: This file has been upgraded from version 1.0 format ****
Names and syntax of some elements may have changed
</xsl:comment>
    <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
  </xsl:template>
  
  <xsl:template match="*|@*|comment()|processing-instruction()|text()">
    <xsl:copy>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="provider">
    <xsl:copy>
      <xsl:if test="not(@class)">
        <xsl:attribute name="class">oracle.portal.provider.v1.http.DefaultProvider</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="@class"/>
      <xsl:if test="@session">
        <session>
          <xsl:value-of select="@session"/>
        </session>
      </xsl:if>
      <xsl:apply-templates select="*|comment()|processing-instruction()|text()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="portlet">
    <xsl:copy>
      <xsl:if test="not(@class)">
        <xsl:attribute name="class">oracle.portal.provider.v1.http.DefaultPortlet</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="@class"/>
      <xsl:if test="@resource">
        <resource>
          <xsl:value-of select="@resource"/>
        </resource>
      </xsl:if>
      <xsl:apply-templates select="*|comment()|processing-instruction()|text()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="portletRenderer">
    <renderer>
      <xsl:if test="not(@class)">
        <xsl:attribute name="class">oracle.portal.provider.v1.http.PageRenderer</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </renderer>
  </xsl:template>

  <xsl:template match="portlet/timeoutMsg">
    <timeoutMessage>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </timeoutMessage>
  </xsl:template>

  <xsl:template match="acceptContentTypes">
    <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
  </xsl:template>

  <xsl:template match="acceptContentTypes/item">
    <acceptContentType>
      <xsl:value-of select="."/>
    </acceptContentType>
  </xsl:template>

  <xsl:template match="portlet/inputParameters">
    <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
  </xsl:template>

  <xsl:template match="portlet/inputParameters/parameter">
    <inputParameter>
      <xsl:if test="not(@class)">
        <xsl:attribute name="class">oracle.portal.provider.v1.PortletParameter</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </inputParameter>
  </xsl:template>

  <xsl:template match="portlet/portletPersonalizationManager">
    <personalizationManager>
      <xsl:if test="not(@class)">
        <xsl:attribute name="class">oracle.portal.provider.v1.FilePersonalizationManager</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </personalizationManager>
  </xsl:template>

  <xsl:template match="portlet/portletSecurityManager">
    <securityManager>
      <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
    </securityManager>
  </xsl:template>

</xsl:stylesheet>
